package stat;

import java.util.HashMap;
import java.util.Iterator;



public class Entropy {

	
	/**
	 * Computes the entropy of s long substrings in str
	 * @param <I>
	 * @param str
	 * @param s
	 * @return
	 */
	public <I> double computeEntropy(String str,int s) {
		return computeEntropy(new SubstringIterator(str,s));
	}
	
	public <I> double computeEntropy(Iterator<I> it) {
		double s = 0;
		HashMap<I,MutableInteger> c = new HashMap<I, MutableInteger>();
		while (it.hasNext()) {
			I n = it.next();
			MutableInteger d = c.get(n);
			if (d==null) c.put(n, d=new MutableInteger(0));
			d.N++;
			s++;
		}
		double re = 0;
		for (MutableInteger d : c.values()) 
			re+=d.N/s*Math.log(d.N/s)/Math.log(2);
		return -re;
	}
	
	private static class SubstringIterator implements Iterator<String> {

		private String s;
		private int l;
		private int o = 0;
		
		public SubstringIterator(String s, int l) {
			this.s = s;
			this.l = l;
		}

		@Override
		public boolean hasNext() {
			return o+l<=s.length();
		}

		@Override
		public String next() {
			String re = s.substring(o,o+l);
			o++;
			return re;
		}

		@Override
		public void remove() {}
		
	}
	
	private static class MutableInteger extends Number implements Comparable<MutableInteger>{
		public int N;
		public MutableInteger(int N) {
			this.N = N;
		}
		@Override
		public String toString() {
			return N+"";
		}
		@Override
		public double doubleValue() {
			return N;
		}
		@Override
		public float floatValue() {
			return N;
		}
		@Override
		public int intValue() {
			return N;
		}
		@Override
		public long longValue() {
			return N;
		}
		@Override
		public int compareTo(MutableInteger o) {
			return N-o.N;
		}
		@Override
		public boolean equals(Object obj) {
			if (!(obj instanceof MutableInteger))
				return false;
			MutableInteger n = (MutableInteger) obj;
			return N==n.N;
		}
		@Override
		public int hashCode() {
			return N;
		}
	}
}